//
//  SENTPublicDefinitions.h
//  SENTSDK
//
//  Created by Emu on 28/07/2017.
//  Copyright © 2018 Sentiance. All rights reserved.
//

#ifndef SENTPublicDefinitions_h
#define SENTPublicDefinitions_h

/** Authentication status items */
typedef NS_ENUM(NSUInteger, SENTInitIssue) {
    /** Given App ID and Secret pair is invalid */
    SENTInitIssueInvalidCredentials,
    /** Given App ID and Secret pair has been changed */
    SENTInitIssueChangedCredentials,
    /** Service unreachable due to network. Most likely due to network or availability issues. */
    SENTInitIssueServiceUnreachable,
    /** Meta user linking failed */
    SENTInitIssueLinkFailed,
    /** Reset of the SDK is in progress*/
    SENTInitIssueResetInProgress
};

/** Defines the status of the SDK */
typedef NS_ENUM(NSUInteger, SENTStartStatus) {
    /** SDK not started yet */
    SENTStartStatusNotStarted,
    /** SDK initialization in progress */
    SENTStartStatusPending,
    /** SDK has started successfuly */
    SENTStartStatusStarted,
    /** SDK has been expired */
    SENTStartStatusExpired
};

/** Current Transportation mode detected by Sentiance SDK */
typedef NS_ENUM(NSUInteger, SENTTransportMode) {
    SENTTransportModeUnknown = 1,
    SENTTransportModeCar = 2,
    SENTTransportModeBicycle = 3,
    SENTTransportModeOnFoot = 4,
    SENTTransportModeTrain = 5,
    SENTTransportModeTram = 6,
    SENTTransportModeBus = 7,
    SENTTransportModePlane = 8,
    SENTTransportModeBoat = 9,
    SENTTransportModeMetro = 10,
    SENTTransportModeRunning = 11
};

/** Deprecated.
    - External event type definition for SDK trigger
 */
typedef NS_ENUM(NSUInteger, SENTExternalEventType) {
    SENTExternalEventTypeOther = 1,
    SENTExternalEventTypeBeacon = 2,
    SENTExternalEventTypeCustomRegion = 3
};

/** Trip trigger status
 - SENTTripTypeSDK: Trip started by SDK.
 - SENTTripTypeExternal: Trip start triggered manually by calling [SENTSDK startTip]
 */

typedef NS_ENUM(NSUInteger, SENTTripType) {
    SENTTripTypeSDK = 1,
    SENTTripTypeExternal = 2
};

#endif /* SENTPublicDefinitions_h */
